==> org.apache.stanbol.entityhub.servicesapi-0.11.0-sources.jar: org/apache/stanbol/entityhub/servicesapi/EntityhubException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.stanbol.entityhub.servicesapi;

/**
 * Indicates an error while performing an operation within the Entityhub.<p>
 * This class is abstract use one of the more specific subclasses
 * @author Rupert Westenthaler
 *
 */
public abstract class EntityhubException extends Exception {

    /**
     * default serial version uid.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Creates an exception with a message and a cause
     * @param reason the message describing the reason for the error
     * @param cause the parent
     */
    protected EntityhubException(String reason, Throwable cause) {
        super(reason, cause);
    }

    /**
     * Creates an exception with a message and a cause
     * @param reason the message describing the reason for the error
     */
    protected EntityhubException(String reason) {
        super(reason);
    }

}

==> org.apache.stanbol.entityhub.servicesapi-0.12.0-sources.jar: org/apache/stanbol/entityhub/servicesapi/EntityhubException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.stanbol.entityhub.servicesapi;

/**
 * Indicates an error while performing an operation within the Entityhub.<p>
 * This class is abstract use one of the more specific subclasses
 * @author Rupert Westenthaler
 *
 */
public abstract class EntityhubException extends RuntimeException {

    /**
     * default serial version uid.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Creates an exception with a message and a cause
     * @param reason the message describing the reason for the error
     * @param cause the parent
     */
    protected EntityhubException(String reason, Throwable cause) {
        super(reason, cause);
    }

    /**
     * Creates an exception with a message and a cause
     * @param reason the message describing the reason for the error
     */
    protected EntityhubException(String reason) {
        super(reason);
    }

}
